Box class

Constructors

Box({int r0 = 0, int r1 = 0, int g0 = 0, int g1 = 0, int b0 = 0, int b1 = 0, int vol = 0})

Properties

b0 ↔ int
getter/setter pair
b1 ↔ int
getter/setter pair
g0 ↔ int
getter/setter pair
g1 ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
r0 ↔ int
getter/setter pair
r1 ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vol ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited