QuantizerWu class

Implemented types

Constructors

QuantizerWu()

Properties

cubes ↔ List<Box>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
moments ↔ List<double>
getter/setter pair
momentsB ↔ List<int>
getter/setter pair
momentsG ↔ List<int>
getter/setter pair
momentsR ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weights ↔ List<int>
getter/setter pair

Methods

computeMoments() → void
constructHistogram(Map<int, int> pixels) → void
createBoxes(int maxColorCount) → CreateBoxesResult
createResult(int colorCount) → List<int>
cut(Box one, Box two) → bool
maximize(Box cube, Direction direction, int first, int last, int wholeR, int wholeG, int wholeB, int wholeW) → MaximizeResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quantize(Iterable<int> pixels, int colorCount) → Future<QuantizerResult>
override
toString() → String
A string representation of this object.
inherited
variance(Box cube) → double

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

maxIndex → int
final
sideLength → int
final
totalSize → int
final

Static Methods

bottom(Box cube, Direction direction, List<int> moment) → int
getIndex(int r, int g, int b) → int
top(Box cube, Direction direction, int position, List<int> moment) → int
volume(Box cube, List<int> moment) → int

Constants

indexBits → const int