TemperatureCache class

Design utilities using color temperature theory.

Analogous colors, complementary color, and cache to efficiently, lazily, generate data for calculations when needed.

Constructors

TemperatureCache(Hct input)

Properties

coldest → Hct
no setter
complement → Hct
A color that complements the input color aesthetically.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hctsByHue → List<Hct>
HCTs for all hues, with the same chroma/tone as the input. Sorted ascending, hue 0 to 360.
no setter
hctsByTemp → List<Hct>
HCTs for all hues, with the same chroma/tone as the input. Sorted from coldest first to warmest last.
no setter
input → Hct
final
inputRelativeTemperature → double
Relative temperature of the input color. See relativeTemperature.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tempsByHct → Map<Hct, double>
A Map with keys of HCTs in hctsByTemp, values of raw temperature.
no setter
warmest → Hct
no setter

Methods

analogous({int count = 5, int divisions = 12}) → List<Hct>
A set of colors with differing hues, equidistant in temperature.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
relativeTemperature(Hct hct) → double
Temperature relative to all colors with the same chroma and tone. Value on a scale from 0 to 1.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isBetween({required double angle, required double a, required double b}) → bool
Determines if an angle is between two other angles, rotating clockwise.
rawTemperature(Hct color) → double
Value representing cool-warm factor of a color. Values below 0 are considered cool, above, warm.